#
# spec file for package python-pyotherside
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define srcname pyotherside
%bcond_without test
Name:           python-pyotherside
Version:        1.6.1
Release:        1.2
Summary:        Asynchronous Python 3 Bindings for Qt 5
License:        ISC
URL:            https://thp.io/2011/pyotherside/
Source:         https://github.com/thp/pyotherside/archive/%{version}.tar.gz
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(python3)
Provides:       pyotherside = %{version}-%{release}
Provides:       python3-pyotherside = %{version}-%{release}
Obsoletes:      python3-pyotherside < %{version}-%{release}
%if %{with test}
BuildRequires:  Mesa-dri
BuildRequires:  xvfb-run
%endif

%description
A QML Plugin that provides access to a Python 3 interpreter from QML.

%prep
%setup -q -n %{srcname}-%{version}
# disable qtquicktests
sed -i 's| qtquicktests||' pyotherside.pro

%build
%qmake5 PYTHON_CONFIG=python%{python3_version}-config QMAKE_STRIP="/bin/true";
%make_build

%install
make INSTALL_ROOT=%{buildroot} install

%if %{with test}
%check
xvfb-run -s '-screen 0, 1280x1024x24' -a  ./tests/tests
%endif

%files
%doc README.md
%license LICENSE
%dir %{_libqt5_archdatadir}/qml/io/
%dir %{_libqt5_archdatadir}/qml/io/thp/
%{_libqt5_archdatadir}/qml/io/thp/pyotherside

%changelog
* Thu Jun 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.6.1:
  * Dropped support for Python < 3.8 (PR#131)
  * Added support for Python 3.12 (PR#131)
  * Support for Qt 6.5 and newer (backwards-incompatible
    ``Q_RETURN_ARG()`` change) (fixes #128)
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.6.0:
  * PyOtherSide now supports Qt 6 while retaining source
    compatibility with Qt 5.
  * PyGLArea is currently broken with Qt 6, use PyFBO
    instead.
* Mon Mar  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.9:
  * New version to support python 3.8+
* Fri May 10 2019 t.gruner@katodev.de
- update to version 1.5.4git (commit ebe2845 on 8 Feb 2019)
  * Initialize sys.argv in Python for libraries that depend on it (issue #77)
  * Update plugins.qmltypes and cleanup project files (by martyone, PR#95)
  * Allow calling signals on QML objects from Python (issue #98)
* Tue Jan  1 2019 t.gruner@katodev.de
- fix build for Factory
- update plugins.qmltypes (commit 067e3a6 on 27 Aug 2018)
* Tue Apr 10 2018 t.gruner@katodev.de
- disable qtquicktests (debug files)
* Thu Jan 25 2018 t.gruner@katodev.de
- fix build for Leap (debug files)
* Thu Jan  4 2018 t.gruner@katodev.de
- cleanup spec file
* Fri Oct 27 2017 dmacvicar@suse.de
- update to 1.5.3
- disable python2
* Thu Jun  1 2017 t.gruner@katodev.de
- Initial release 1.5.1
